"""The version number is based on semantic versioning.

References
- https://semver.org/
- https://www.python.org/dev/peps/pep-0440/

This file is autogenerated, do not modify by hand.
"""
__version__ = "1.1.0-beta.11"
COMMIT = "28ccb3d92f1f2c7b5397dd49bdf0c4d914b852f3"
MAJOR = 1
MINOR = 1
PATCH = 0
